//+------------------------------------------------------------------+
//|                                       BCDX3Crossover_Ticket0.mq4 |
//|                      Copyright  2005, MetaQuotes Software Corp. |
//|                                       http://www.metaquotes.net/ |
//+------------------------------------------------------------------+
#define MAGICMA  20050610

extern double Lots               = 0.1;
extern double MaximumRisk        = 0.01;
extern int MaximumLots           = 2;
extern int MaximumNumberofTrades = 2;
extern bool OpenNewTrades        = False;
int OpenTrades                   = 0;
extern double DecreaseFactor     = 3;
extern double MovingPeriod       = 21;
extern double MovingShift        = 0;


//+------------------------------------------------------------------+
//| Calculate open positions                                         |
//+------------------------------------------------------------------+
int CalculateCurrentOrders(string symbol)
  {
   int buys=0,sells=0;
//----
   for(int i=0;i<OrdersTotal();i++)
     {
      if(OrderSelect(i,SELECT_BY_TICKET,MODE_TRADES)==false) break;
      if(OrderSymbol()==Symbol() && OrderMagicNumber()==MAGICMA)
        {
         if(OrderType()==OP_BUY)  buys++;
         if(OrderType()==OP_SELL) sells++;
        }
     }
//---- return orders volume
   if(buys>0) return(buys);
   else       return(-sells);
//---- Check for Maximum Trades
   if(OpenTrades==MaximumNumberofTrades) OpenNewTrades = False; 
  }
//+------------------------------------------------------------------+
//| Calculate optimal lot size                                       |
//+------------------------------------------------------------------+
double LotsOptimized()
  {
   double lot=Lots;
   int    orders=HistoryTotal();     // history orders total
   int    losses=0;                  // number of losses orders without a break
//---- select lot size
   lot=NormalizeDouble(AccountFreeMargin()*MaximumRisk/1000.0,1);
//---- calcuulate number of losses orders without a break
   if(DecreaseFactor>0)
     {
      for(int i=orders-1;i>=0;i--)
        {
         if(OrderSelect(i,SELECT_BY_TICKET,MODE_HISTORY)==false) { Print("Error in history!"); break; }
         if(OrderSymbol()!=Symbol() || OrderType()>OP_SELL) continue;
         //----
         if(OrderProfit()>0) break;
         if(OrderProfit()<0) losses++;
        }
      if(losses>1) lot=NormalizeDouble(lot-lot*losses/DecreaseFactor,1);
     }
//---- return lot size
   if(lot<0.1) lot=0.1;
   return(lot);
  }
//+------------------------------------------------------------------+
//| Check for open order conditions                                  |
//+------------------------------------------------------------------+
void CheckForOpen()
  {string st;
   double ma;
   double adx;
   double adx2;
   double adx3; 
   double adx1;
   double adx21;
   double adx31; 
   double atr;
   double atr2;
   bool is_siesta=false;
   int    res;
//----Stop Trades on number of Trades
     
//---- go trading only for first tiks of new bar
   if(Volume[0]>1) return;
//---- get Moving Average 
   ma=iMA(NULL,0,MovingPeriod,MovingShift,MODE_SMA,PRICE_CLOSE,0);
   adx=iADX(NULL,0,7,PRICE_CLOSE,MODE_MAIN,0);
   adx2=iADX(NULL,0,14,PRICE_CLOSE,MODE_MAIN,0);
   adx3=iADX(NULL,0,21,PRICE_CLOSE,MODE_MAIN,0);
   adx1=iADX(NULL,0,7,PRICE_CLOSE,MODE_MAIN,1);
   adx21=iADX(NULL,0,14,PRICE_CLOSE,MODE_MAIN,1);
   adx31=iADX(NULL,0,21,PRICE_CLOSE,MODE_MAIN,1);
   atr=iATR(NULL,0,5,0);
   atr2=iATR(NULL,0,14,1);

//---- sell conditions
   if((adx<adx1 && adx2>adx21) && (adx3>adx31 && adx>=+10))
     
     void PlaySound("alert.wav");
     Alert("Alarm triggered by ",Symbol());
     // Alarm

     if(Hour()>=12 || Hour()<=24)  is_siesta=false;
      
     {
      res=OrderSend(Symbol(),OP_SELL,LotsOptimized(),Bid,3,0,0,"",MAGICMA,0,Red);
      return;
     }
//---- buy conditions
   if((adx<adx1 && adx2>adx21) && (adx3>adx31 && adx>=-10))
     if(Hour()>=12 || Hour()<17)  is_siesta=false;

     {
      res=OrderSend(Symbol(),OP_BUY,LotsOptimized(),Ask,3,0,0,"",MAGICMA,0,Blue);
      return;
     }
//----
  }
//+------------------------------------------------------------------+
//| Check for close order conditions                                 |
//+------------------------------------------------------------------+
void CheckForClose()
  {
   double ma;
   double atr;
   double atr2;   
//---- go trading only for first tiks of new bar
   if(Volume[0]>1) return;
//----
   for(int i=0;i<OrdersTotal();i++)
     {
      if(OrderSelect(i,SELECT_BY_POS,MODE_TRADES)==false)        break;
      if(OrderMagicNumber()==MAGICMA || OrderSymbol()==Symbol()) continue;
      //---- check order type 
      if(OrderType()==OP_BUY)
        {
        if(Close[0]<ma) OrderClose(OrderTicket(),OrderLots(),Bid,3,White);
         break;
        }
      if(OrderType()==OP_SELL)
        {
         if(Close[0]>ma) OrderClose(OrderTicket(),OrderLots(),Ask,3,White);
         break;
        }
     }
//----
  }
//+------------------------------------------------------------------+
//| Start function                                                   |
//+------------------------------------------------------------------+
void start()
  {
//---- check for history and trading
   if(Bars<100 || IsTradeAllowed()==false) return;
//---- calculate open orders by current symbol
   if(CalculateCurrentOrders(Symbol())==0) CheckForOpen();
   else                                    CheckForClose();
//----
  }
//+------------------------------------------------------------------+